/*
 * Copyright (C) 2009-2012 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.bus;

/**
 * {@code NotExposedException} is thrown by {@code Exposer} if a service may not 
 * be exposed from {@code Exposer} or cannot be identified from 
 * {@code Repository}.
 *
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
public class NotExposedException extends RuntimeException {

	private static final long serialVersionUID = -1655543544514155744L;

	/** Constructs a new {@code NotExposedException}. */
	public NotExposedException() {}

	/**
	 * Constructs a new {@code NotExposedException} with the specified message.
	 * 
	 * @param message The detail message.
	 */
	public NotExposedException(String message) {
		super(message);
	}

	/**
	 * Constructs a new {@code NotExposedException} with the root cause.
	 * 
	 * @param cause The root cause.
	 */
	public NotExposedException(Throwable cause) {
		super(cause);
	}

	/**
	 * Constructs a new {@code NotExposedException} with the specified message 
	 * and root cause.
	 * 
	 * @param message The detail message.
	 * @param cause The root cause.
	 */
	public NotExposedException(String message, Throwable cause) {
		super(message, cause);
	}

}
