/*
 * Copyright (C) 2009-2011 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.deployment;

import java.util.Set;

import org.eiichiro.jazzmaster.service.Service;

/**
 * {@code Scanner} loads service definition classes and service implementation 
 * classes from own managed search path.
 * This interface is extensible. You can implement this interface implementation 
 * class loading them from your own search path. Your own {@code Scanner} 
 * implementation class must obey the following rules: 
 * <ul>
 * <li>A scanner implementation class has a default constructor for the 
 * Jazzmaster dependency injection working.</li>
 * <li>A scanner implementation class is stored on the classpath.</li>
 * </ul>
 *
 * @see Deployer
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
public interface Scanner {

	/**
	 * Scans service definition classes and service implementation classes from 
	 * own search path.
	 * This method will be invoked by deployer after configured this 
	 * implementation instance.
	 */
	public void scan();
	
	/**
	 * Returns the service definition classes that this interface implementation 
	 * instance has scanned.
	 * 
	 * @return The service definition classes that this interface implementation 
	 * instance has scanned.
	 */
	public Set<Class<? extends Service>> getServices();
	
	/**
	 * Returns the service implementation classes that this interface 
	 * implementation instance has scanned.
	 * This method will be invoked by deployer after {@code #getServices()} 
	 * method is invoked.
	 * 
	 * @return The service implementation classes that this interface 
	 * implementation instance has scanned.
	 */
	public Set<Class<?>> getImplementations();
	
	/**
	 * 
	 * @return
	 */
	public Set<Class<?>> getInterceptors();
	
}
