/*
 * Copyright (C) 2009-2011 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.management;

import java.util.Set;

/**
 * {@code Context} is a Jazzmaster component instance store managed by each 
 * component {@code Scope} that the component is activated.
 * A {@code Scope} must provide the {@code Context} implementation to bind 
 * components into appropriately-scoped context object (e.g. static {@code Set}, 
 * {@code ThreadLocal} and {@code javax.servlet.http.HttpSession}). The 
 * {@code Manager} manages Jazzmaster components by corresponding them to their 
 * scope.
 *
 * @see Scope
 * @see Manager
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
public interface Context {

	/**
	 * Returns the component correspond to the specified key.
	 * 
	 * @param key The key for getting a component.
	 * @return The component that correspond to the specified key.
	 */
	public Object get(Object key);
	
	/**
	 * Puts the key and the component that correspond to the specified key.
	 * 
	 * @param key The key that correspond to the component.
	 * @param value The component that correspond to the key.
	 */
	public void put(Object key, Object value);
	
	/**
	 * Returns all keys this context contains as a {@code Set} view.
	 * 
	 * @return All keys this context contains.
	 */
	public Set<Object> keySet();
	
	/** Cleans up all keys and components that this context contains. */
	public void clear();
	
}
