/*
 * Copyright (C) 2009-2011 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.management;

import static org.eiichiro.jazzmaster.management.Scope.*;

import java.lang.annotation.Documented;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * {@code Scoped} qualifies component activated scope.
 * You can qualify the component scope of your component as the following code: 
 * <pre>
 * package jazzmaster.hello;
 * 
 * import org.eiichiro.jazzmaster.management.Scope;
 * import org.eiichiro.jazzmaster.management.Scoped;
 * import org.eiichiro.jazzmaster.service.Implementation;
 * 
 * {@code @Scoped(Scope.APPLICATION)}
 * {@code @Implementation}
 * public class HelloImpl implements Hello {
 * </pre>
 *
 * @see Scope
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface Scoped {

	/** The scope that your component being managed. */
	Scope value() default DEPENDENT;
	
}
