/*
 * Copyright (C) 2009-2011 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.jazzmaster.service;

import static java.lang.annotation.ElementType.*;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.eiichiro.jazzmaster.kernel.Binding;

/**
 * {@code Named} is a built-in binding annotation to refer a service by name.
 * Service (service definition or service implementation class) is automatically 
 * annotated with this binding annotation. In case of service definition, 
 * service can be referred by the name that {@code Service#getName()} returns. 
 * In case of service implementation class, service can be referred by the 
 * service implementation class's full qualified name. If you obviously annotate 
 * service definition or service implementation class with this binding 
 * annotation, you can also refer by the name you obviously specified with this 
 * binding annotation.
 *
 * @see Binding
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Target({FIELD, TYPE})
@Binding
public @interface Named {

	/** The service name referred by this binding annotation. */
	String value();
	
}
